@@ -460,10 +460,10 @@ class Snaplib:
         alg_names = []
         for alg in algorithms_list:
             alg_name = alg.__class__.__name__[:3]
-            if y_test is not None and alg_name in ['LGB', 'XGB', 'Cat']:
-                model = alg.fit(X_train, y_train, eval_set=[(X_pred, y_test)], early_stopping_rounds=10, verbose=False)
-            else:
-                model = alg.fit(X_train, y_train)
+            # if y_test is not None and alg_name in ['LGB', 'XGB', 'Cat']:
+            #     model = alg.fit(X_train, y_train, eval_set=[(X_pred, y_test)], early_stopping_rounds=10, verbose=False)
+            # else:
+            model = alg.fit(X_train, y_train)
 
             y_hat = model.predict(X_pred)
             if task =='clsf':
@@ -610,8 +610,8 @@ class Snaplib:
                     algorithms_list, 
                     X_train, 
                     y_train, 
-                    X_val=None, 
-                    y_val=None, 
+                    # X_val=None, 
+                    # y_val=None, 
                     verbose=0
                     ):
         
@@ -630,8 +630,7 @@ class Snaplib:
         
         algorithms_list = list of algorithms [LGBMClassifier(), XGBClassifier(), CatBoostClassifier()].
         X_train and y_train are data for training list of algorithms.
-        X_val and y_val are validation set for early_stopping_rounds for 
-        [LGBMClassifier(), XGBClassifier(), CatBoostClassifier()]
+
         verbose = 0 mute, 1 verbose.
         '''
 
@@ -645,27 +644,25 @@ class Snaplib:
         if not isinstance(y_train, pd.core.frame.Series) and not isinstance(y_train, np.ndarray):
             raise TypeError('The y__train must be a pandas.core.frame.Series instance or numpy.ndarray.')
 
-        if X_val is not None:
-            if not isinstance(X_val, pd.core.frame.DataFrame):
-                raise TypeError('The X__val must be a pandas.core.frame.DataFrame instance.')
-        if y_val is not None:
-            if not isinstance(y_val, pd.core.frame.Series) and not isinstance(y_val, np.ndarray):
-                raise TypeError('The y__val must be a pandas.core.frame.Series instance or numpy.ndarray.')
+        # if X_val is not None:
+        #     if not isinstance(X_val, pd.core.frame.DataFrame):
+        #         raise TypeError('The X__val must be a pandas.core.frame.DataFrame instance.')
+        # if y_val is not None:
+        #     if not isinstance(y_val, pd.core.frame.Series) and not isinstance(y_val, np.ndarray):
+        #         raise TypeError('The y__val must be a pandas.core.frame.Series instance or numpy.ndarray.')
 
         if type(verbose) != int and type(verbose) != bool:
             raise TypeError('verbose must be of int type or bool.')
 
-        return_trained_models = []
 
         for alg in algorithms_list:
-            alg_name = alg.__class__.__name__[:3]
-            if X_val is not None and y_val is not None and alg_name in ['LGB', 'XGB', 'Cat']:
-                model = alg.fit(X_train, y_train, eval_set=[(X_val, y_val)], early_stopping_rounds=10, verbose=verbose)
-            else:
-                model = alg.fit(X_train, y_train)
-            return_trained_models.append(model)
+            # alg_name = alg.__class__.__name__[:3]
+            # if X_val is not None and y_val is not None and alg_name in ['LGB', 'XGB', 'Cat']:
+            #     alg.fit(X_train, y_train, eval_set=[(X_val, y_val)], early_stopping_rounds=10, verbose=verbose)
+            # else:
+            alg.fit(X_train, y_train)
 
-        return return_trained_models
+        return algorithms_list
     
     
 
